@@ -49,6 +49,7 @@ LOCATIONS = [
     'g',  # 415 Main Street / 7 Cambridge Center
     'i',  # 50 Inner Belt
     'l',  # LIMS Network
+    'm',  # Markley Lowell
     'r',  # Remote site (ex. Oxford Street)
     's',  # 1 Summer Street
     'v',  # 5 Cambridge Center (decommissioned)
@@ -285,16 +286,16 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
     def check_duplicates(self):
         """Check entries for duplicates."""
         # add round robins first
-        for hostname in self.round_robins:
-            self.hostnames[hostname] = self.round_robins[hostname]
+        for hostname, data in self.round_robins.items():
+            self.hostnames[hostname] = data
 
         # add cnames, mx records and ns record next
-        for hostname in self.cnames:
-            self.hostnames[hostname] = self.cnames[hostname]
-        for hostname in self.mxs:
-            self.hostnames[hostname] = self.mxs[hostname]
-        for hostname in self.nss:
-            self.hostnames[hostname] = self.nss[hostname]
+        for hostname, data in self.cnames.items():
+            self.hostnames[hostname] = data
+        for hostname, data in self.mxs.items():
+            self.hostnames[hostname] = data
+        for hostname, data in self.nss.items():
+            self.hostnames[hostname] = data
 
         # check reserved IPs for duplicates
         self.check_duplicate_reserved_ips()
@@ -489,33 +490,33 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
         # now that we've turned the entries into records, check for duplicates
 
         # cnames
-        for hostname in self.cnames:
+        for hostname, data in self.cnames.items():
             if hostname not in self.records:
-                self.records[hostname] = self.cnames[hostname]
+                self.records[hostname] = data
             else:
                 error = 'Duplicate Record [CNAME]: %s' % (hostname)
                 line.errors.append(error)  # pylint:disable=undefined-loop-variable
 
         # mx records
-        for hostname in self.mxs:
+        for hostname, data in self.mxs.items():
             if hostname not in self.records:
-                self.records[hostname] = self.mxs[hostname]
+                self.records[hostname] = data
             else:
                 error = 'Duplicate Record [MX]: %s' % (hostname)
                 line.errors.append(error)  # pylint:disable=undefined-loop-variable
 
         # ns records
-        for hostname in self.nss:
+        for hostname, data in self.nss.items():
             if hostname not in self.records:
-                self.records[hostname] = self.nss[hostname]
+                self.records[hostname] = data
             else:
                 error = 'Duplicate Record [NS]: %s' % (hostname)
                 line.errors.append(error)  # pylint:disable=undefined-loop-variable
 
         # hosts
-        for hostname in self.hosts:
+        for hostname, data in self.hosts.items():
             if hostname not in self.records:
-                self.records[hostname] = self.hosts[hostname]
+                self.records[hostname] = data
             else:
                 error = 'Duplicate Record [Host]: %s' % (hostname)
                 line.errors.append(error)  # pylint:disable=undefined-loop-variable
@@ -523,8 +524,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
     def get_record_types(self):
         """Return a dict of the record types in the file."""
         record_types = {}
-        for hostname in self.records:
-            record = self.records[hostname]
+        for _, record in self.records.items():
             record_type = record.type
             if record_type in record_types:
                 record_types[record_type] += 1
@@ -535,8 +535,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
     def get_round_robins(self):
         """Get round robin hosts."""
         round_robins = {}
-        for hostname in self.hosts:
-            host = self.hosts[hostname]
+        for _, host in self.hosts.items():
             if host.round_robin:
                 round_robin = host.round_robin
                 if round_robin in round_robins:
@@ -575,8 +574,7 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
         for username in people:
             emplids[username] = people[username]['emplid']
         # update all hosts
-        for hostname in self.hosts:
-            host = self.hosts[hostname]
+        for hostname, host in self.hosts.items():
             username = host.username.replace('-', '')
             if not username:
                 continue
